
/***************************************************
* By CCSC compiler
*  File Name: 20201014_K643_MK200C_1705.c
 * rev 1.0
*  Description: get sound from microphone and turn on relay
*  RC0 in opemp opain1+, 
*  RC1 in opamp opa1in-
*  RC2 in opamp opa1out
*  RC3 in opemp opa2out,
*  RC4 in opamp opa2in-
*  RC5 in opamp opa2in+
*  RA0 in ADC, potentiometer, frequency
*  RA1 in sw2
*  RA2 out ss1
*  RA3 in sw1
*  RA4 in sdo1
*  RA5 in sck1
*  COPYRIGHT 2020 MYCOMKITS.COM, owned by CNET LIMITED
* The copyright of this program belongs to the producer "MYCOMKITS.COM management company CNET LIMITED". 
* We do not abandon copyright, but you can use and change the program in learning using this program. 
***************************************************/
//
#include <16F1705.h>
#DEVICE ADC=10
#fuses	INTRC_IO, NOWDT, NOMCLR, NOBROWNOUT, PUT, NOPROTECT, NODEBUG
#fuses	NOCLKOUT, NOWRT
#use	delay(CLOCK = 4000000)
#use spi(MASTER, FORCE_SW, SAMPLE_FALL, DO=PIN_A4, CLK=PIN_A5, ENABLE=PIN_A2, MODE=2, STREAM=AD9833)   // 20181125 worked, 

#include <math.h>
//
#use   fast_io(a)  //a5 to 0
#use   fast_io(c)  //C5 to 0
//
#define Amode 0xCB         //port A all input, except A2, 4, 5
#define Cmode 0xFF         //port C all input
#define sw1 PIN_A3
#define sw2 PIN_A1
#define AD9833_CS PIN_A2
#define sine 0
#define squa 1
#define tria 2
//
#byte OSCCON = 0x08F
#byte WPUA = 0x20C
#byte WPUC = 0x20E
#byte OPTION_REG = 0x095
#byte PCON = 0x10F
#byte OPA1CON = 0x096
#byte ANSELC = 0x187

// variables
long long frequency_value=0;
int mode_wave =sine;

// prototyping
#separate
void initializing();
#separate
void set_freq();
#separate
void set_dss();
#separate
void dss_clear();
#separate
void get_pot();
#separate
void get_function();
#separate
void test();

// main function
void main()
{
   initializing();
   
   // main loop
   while(1)
   {
       get_pot();
       get_function();
       set_dss();   //frequency_value
       //test();
   }
}
//
#separate
void initializing()
{
   set_tris_a(Amode);   //
   set_tris_c(Cmode);   //
   //
   setup_comparator(NC_NC_NC_NC);
   // A/D converter initialize
   setup_adc(ADC_CLOCK_DIV_8);   // 2usec
   setup_adc_ports(sAN0 | VSS_VDD);    // PIN_A0
   //
   setup_opamp1(OPAMP_ENABLED | OPAMP_I_TO_OPAIN | OPAMP_NI_TO_OPAIN);
   setup_opamp2(OPAMP_ENABLED | OPAMP_I_TO_OUTPUT | OPAMP_NI_TO_OPAIN);
   // timer 1 intialize for hysteresis count down
   setup_timer_1(T1_INTERNAL|T1_DIV_BY_8); //8us
   set_timer1(0xE797);              // timer 1 setting almost 50msec

   port_a_pullups(0x0A);    //A3, 1
   port_c_pullups(0);   
   
   output_high(AD9833_CS);
   if(input(sw1) == 0)
   {
        mode_wave==sine; //sine=0
   }
   else mode_wave==squa; //squa=1
   //
   delay_ms(100);
}
//set Dss
#separate
void set_dss()
{
    long dss_value_tempo;
    long dss_value_tempo2;
    float dss_value_f;
    long long dss_value_L;
    //
    dss_value_f =frequency_value;  //1Hz to 10230Hz
    dss_value_f =  dss_value_f * 10.73741824;  //
    dss_value_L = dss_value_f;
    dss_value_tempo = dss_value_L;
    dss_value_tempo2 = dss_value_L >> 14;
    dss_value_tempo = dss_value_tempo & 0x3FFF;
    dss_value_tempo2 = dss_value_tempo2 & 0x3FFF;
    dss_value_tempo2 = dss_value_tempo2 + 0x4000;
    dss_value_tempo = dss_value_tempo + 0x4000;
    
    if(mode_wave == sine) spi_xfer (AD9833, 0x2000, 16); // 2000, not 2100
    else if(mode_wave == squa) spi_xfer (AD9833, 0x2068, 16);
    else spi_xfer (AD9833, 0x2002, 16);
    spi_xfer(AD9833, dss_value_tempo, 16);   //0b0101100010010011
    spi_xfer(AD9833, dss_value_tempo2, 16);   //freq0 14MSB, 0
    spi_xfer(AD9833, 0xC000, 16);   //PHASE0, 0
    if(mode_wave == sine) spi_xfer (AD9833, 0x2000, 16); // 2000, not 2100
    else if(mode_wave == squa) spi_xfer (AD9833, 0x2068, 16);
    else spi_xfer (AD9833, 0x2002, 16); 

}
//
#separate
void dss_clear()
{
    output_low(AD9833_CS);
    spi_xfer(AD9833, 0x0100, 16); //reset
    spi_xfer(AD9833, 0x2000, 16); //fselect
    spi_xfer(AD9833, 0x4000, 16);   //freq0 14LSB, 0
    spi_xfer(AD9833, 0x4000, 16);   //freq0 14MSB, 0
    spi_xfer(AD9833, 0xC000, 16);   //PHASE0, 0
    spi_xfer(AD9833, 0xE000, 16);   //PHASE1, 0
    //spi_xfer(AD9833, 0x0000, 16);   //
    output_high(AD9833_CS);
}
//
#separate
void get_pot()
{
    set_adc_channel(0);   //must wait 65u, RA1
   delay_us(100);
   frequency_value = read_adc();   //0 to 1023
   frequency_value = frequency_value * 10;  //0 to 10230, 0hz to 10khz
   if(frequency_value == 0) frequency_value=1;  //1 to 10230
}
//
#separate
void get_function()
{
    if(input(sw1) == 0) mode_wave=sine;
    else if(input(sw2)==0) mode_wave=tria;
    else mode_wave=squa;
}
//
#separate
void test()
{
    if(frequency_value <= 10000)
    {
        frequency_value=frequency_value+100;
    }
    else frequency_value = 100;
    delay_ms(100);
}


